@@ -18,10 +18,10 @@ class Hubspot3UsageLimits:
 
     def __init__(
         self,
-        collected_at: datetime = datetime.fromtimestamp(0),
+        collected_at: datetime = datetime.now(),
         current_usage: int = 0,
         fetch_status: str = FetchStatus.NONE,
-        resets_at: datetime = datetime.fromtimestamp(0),
+        resets_at: datetime = datetime.now(),
         usage_limit: int = 0,
     ) -> None:
         """usage limits constructor"""
@@ -53,7 +53,9 @@ class Hubspot3UsageLimits:
     @property
     def until_cache_expire(self):
         """returns the number of seconds until the cache expires, and we need an update"""
-        return int((self.collected_at + timedelta(minutes=5) - datetime.now()).total_seconds())
+        return int(
+            (self.collected_at + timedelta(minutes=5) - datetime.now()).total_seconds()
+        )
 
     @property
     def calls_remaining(self) -> int:
@@ -73,7 +75,10 @@ class Hubspot3UsageLimits:
         :see: https://developers.hubspot.com/docs/methods/check-daily-api-usage
         """
         five_minutes_ago = datetime.now() - timedelta(minutes=5)
-        if self.collected_at and self.collected_at > five_minutes_ago:
+        if (
+            self.fetch_status != self.FetchStatus.NONE
+            and self.collected_at > five_minutes_ago
+        ):
             return False
         return True
 
@@ -87,6 +92,7 @@ class Hubspot3:
         access_token: str = None,
         refresh_token: str = None,
         client_id: str = None,
+        client_secret: str = None,
         timeout: int = 10,
         api_base: str = "api.hubapi.com",
         debug: bool = False,
@@ -94,10 +100,11 @@ class Hubspot3:
         **extra_options: Any
     ) -> None:
         """full client constructor"""
-        self.api_key = api_key or extra_options.get("api_key")
-        self.access_token = access_token or extra_options.get("access_token")
-        self.refresh_token = refresh_token or extra_options.get("refresh_token")
-        self.client_id = client_id or extra_options.get("client_id")
+        self.api_key = api_key
+        self.access_token = access_token
+        self.refresh_token = refresh_token
+        self.client_id = client_id
+        self.client_secret = client_secret
         if not disable_auth:
             if self.api_key and self.access_token:
                 raise HubspotBadConfig("Cannot use both api_key and access_token.")
@@ -107,6 +114,7 @@ class Hubspot3:
             "access_token": self.access_token,
             "api_key": self.api_key,
             "client_id": self.client_id,
+            "client_secret": self.client_secret,
             "refresh_token": self.refresh_token,
         }
         self.options = {
@@ -134,6 +142,20 @@ class Hubspot3:
 
         return BlogClient(**self.auth, **self.options)
 
+    @property
+    def blog_comments(self):
+        """returns a hubspot3 blog comments client"""
+        from hubspot3.blog import BlogCommentsClient
+
+        return BlogCommentsClient(**self.auth, **self.options)
+
+    @property
+    def blog_topics(self):
+        """returns a hubspot3 blog topics client"""
+        from hubspot3.blog import BlogTopicsClient
+
+        return BlogTopicsClient(**self.auth, **self.options)
+
     @property
     def broadcast(self):
         """returns a hubspot3 broadcast client"""
@@ -141,6 +163,20 @@ class Hubspot3:
 
         return BroadcastClient(**self.auth, **self.options)
 
+    @property
+    def cms_layouts(self):
+        """returns a hubspot3 layouts client"""
+        from hubspot3.cms_layouts import CMSLayoutsClient
+
+        return CMSLayoutsClient(**self.auth, **self.options)
+
+    @property
+    def cms_templates(self):
+        """returns a hubspot3 templates client"""
+        from hubspot3.cms_templates import CMSTemplatesClient
+
+        return CMSTemplatesClient(**self.auth, **self.options)
+
     @property
     def companies(self):
         """returns a hubspot3 companies client"""
@@ -148,6 +184,13 @@ class Hubspot3:
 
         return CompaniesClient(**self.auth, **self.options)
 
+    @property
+    def companies_properties(self):
+        """returns a hubspot3 companies properties client"""
+        from hubspot3.companies_properties import CompaniesPropertiesClient
+
+        return CompaniesPropertiesClient(**self.auth, **self.options)
+
     @property
     def contact_lists(self):
         """returns a hubspot3 contact_lists client"""
@@ -183,6 +226,27 @@ class Hubspot3:
 
         return DealsClient(**self.auth, **self.options)
 
+    @property
+    def ecommerce_bridge(self):
+        """returns a hubspot3 ecommerce bridge client"""
+        from hubspot3.ecommerce_bridge import EcommerceBridgeClient
+
+        return EcommerceBridgeClient(**self.auth, **self.options)
+
+    @property
+    def email_events(self):
+        """returns a hubspot3 email events client"""
+        from hubspot3.email_events import EmailEventsClient
+
+        return EmailEventsClient(**self.auth, **self.options)
+
+    @property
+    def email_subscription(self):
+        """returns a hubspot3 email subscription client"""
+        from hubspot3.email_subscription import EmailSubscriptionClient
+
+        return EmailSubscriptionClient(**self.auth, **self.options)
+
     @property
     def engagements(self):
         """returns a hubspot3 engagements client"""
@@ -218,6 +282,20 @@ class Hubspot3:
 
         return LeadsClient(**self.auth, **self.options)
 
+    @property
+    def lines(self):
+        """returns a hubspot3 lines client"""
+        from hubspot3.lines import LinesClient
+
+        return LinesClient(**self.auth, **self.options)
+
+    @property
+    def oauth2(self):
+        """returns a hubspot3 OAuth2 client"""
+        from hubspot3.oauth2 import OAuth2Client
+
+        return OAuth2Client(**self.auth, **self.options)
+
     @property
     def owners(self):
         """returns a hubspot3 owners client"""
@@ -232,6 +310,20 @@ class Hubspot3:
 
         return ProductsClient(**self.auth, **self.options)
 
+    @property
+    def properties(self):
+        """returns a hubspot3 deal properties client"""
+        from hubspot3.properties import PropertiesClient
+
+        return PropertiesClient(**self.auth, **self.options)
+
+    @property
+    def property_groups(self):
+        """returns a hubspot3 property_groups client"""
+        from hubspot3.property_groups import PropertyGroupsClient
+
+        return PropertyGroupsClient(**self.auth, **self.options)
+
     @property
     def prospects(self):
         """returns a hubspot3 prospects client"""
@@ -253,9 +345,16 @@ class Hubspot3:
 
         return TicketsClient(**self.auth, **self.options)
 
+    @property
+    def workflows(self):
+        """returns a hubspot3 workflows client"""
+        from hubspot3.workflows import WorkflowsClient
+
+        return WorkflowsClient(**self.auth, **self.options)
+
     @property
     def usage_limits(self):
-        """fetches and returns a nice usage liimitation object"""
+        """fetches and returns a nice usage limitation object"""
         if self._usage_limits.need_update:
             limits = self._base._call("integrations/v1/limit/daily")[0]
             self._usage_limits = Hubspot3UsageLimits(
@@ -268,7 +367,7 @@ class Hubspot3:
         return self._usage_limits
 
     @property
-    def me(self):
+    def me(self):  # pylint: disable=invalid-name
         """
         returns info about your hubspot account
         :see: https://developers.hubspot.com/docs/methods/get-account-details
