@@ -1,6 +1,7 @@
 """
 hubspot owners api
 """
+from hubspot3.crm_associations import CRMAssociationsClient
 from hubspot3.base import BaseClient
 
 
@@ -22,9 +23,9 @@ class OwnersClient(BaseClient):
         return self._call("owners", **options)
 
     def get_owner_name_by_id(self, owner_id: str, **options) -> str:
-        """given an id of an owner, return their name"""
+        """Given an id of an owner, return their name"""
         owner_name = "value_missing"
-        owners = self.get_owners()
+        owners = self.get_owners(**options)
         for owner in owners:
             if int(owner["ownerId"]) == int(owner_id):
                 owner_name = "{} {}".format(owner["firstName"], owner["lastName"])
@@ -33,8 +34,31 @@ class OwnersClient(BaseClient):
     def get_owner_email_by_id(self, owner_id: str, **options) -> str:
         """given an id of an owner, return their email"""
         owner_email = "value_missing"
-        owners = self.get_owners()
+        owner = self.get_owner_by_id(owner_id, **options)
+        if owner:
+            owner_email = owner["email"]
+        return owner_email
+
+    def get_owner_by_id(self, owner_id, **options):
+        """Retrieve an owner by its id."""
+        owners = self.get_owners(**options)
         for owner in owners:
             if int(owner["ownerId"]) == int(owner_id):
-                owner_email = owner["email"]
-        return owner_email
+                return owner
+        return None
+
+    def get_owner_by_email(self, owner_email: str, **options):
+        """
+        Retrieve an owner by its email.
+        """
+        owners = self.get_owners(method="GET", params={"email": owner_email}, **options)
+        if owners:
+            return owners[0]
+        return None
+
+    def link_owner_to_company(self, owner_id, company_id):
+        """
+        Link an owner to a company by using their ids.
+        """
+        associations_client = CRMAssociationsClient(**self.credentials)
+        return associations_client.link_owner_to_company(owner_id, company_id)
